# (c) Copyright 2016 Synapse Wireless, Inc.
''' The job of this class is to format (snaplayout) a memory image of the passed in Intel HEX file
    that matches the needs of the CC1310 "Boot Helper".'''
#
# This was originally a much larger class, but the common functionality was factored out
# into a new class, CoreLayout, which this class now customizes.
#

import CoreLayout
import pyintelhex # pyintelhex.IntelHexReader() will be our "CoreReader"

class CC1310_Layout(CoreLayout.CoreLayout):
    CORE_PART1_START_ADDRESS = 0x00000 # Interrupt vectors, main2(), boot helper, SNAP Core
    CORE_PART1_END_ADDRESS   = 0x0DFFF #

    # The following is used to detect foolish users trying to load OLD firmware (that predates FOTA)
    # We had to change the memory map to support this feature, the older (bad) files have CODE
    # in the portion of FLASH where now only SCRIPTS are allowed.
    CORE_DISALLOWED_START_ADDRESS = 0x0F000 # Only scripts go here in the new (>= 2.4.32) firmware
    CORE_DISALLOWED_END_ADDRESS   = 0x1EFFF # 

    def __init__(self, contents):
        super(CC1310_Layout, self).__init__(
            pyintelhex.IntelHexReader(),
            contents,
            ((self.CORE_PART1_START_ADDRESS, self.CORE_PART1_END_ADDRESS),),
            ((self.CORE_DISALLOWED_START_ADDRESS, self.CORE_DISALLOWED_END_ADDRESS),),
            32 * 1024 # <- because the actual Boot Helper enforces this requirement...
        )

    # for the rest of the story, see CoreLayout.py
